--[[----------------------------------------------------------------------------

EcoSeeExportDialogSections.lua
Export dialog customization for Lightroom EcoSee uploader

--------------------------------------------------------------------------------

ADOBE SYSTEMS INCORPORATED
 Copyright 2007 Adobe Systems Incorporated
 All Rights Reserved.

NOTICE: Adobe permits you to use, modify, and distribute this file in accordance
with the terms of the Adobe license agreement accompanying it. If you have received
this file from a source other than Adobe, then your use, modification, or distribution
of it requires the prior written permission of Adobe.

------------------------------------------------------------------------------]]

	-- Lightroom SDK
local LrBinding = import 'LrBinding'
local LrView = import "LrView"

local bind = LrView.bind
local share = LrView.share

--============================================================================--

EcoSeeExportDialogSections = {}

-------------------------------------------------------------------------------

function EcoSeeExportDialogSections.startDialog( propertyTable )

	-- Can't export until we've validated the login.

	propertyTable.LR_canExport = false

	-- Make sure we're logged in.

	require 'EcoSeeUser'
	EcoSeeUser.verifyLogin( propertyTable )

	propertyTable:addObserver( 'validAccount',
		function()
			propertyTable.LR_canExport = propertyTable.validAccount
		end )
		
end

-------------------------------------------------------------------------------

function EcoSeeExportDialogSections.sectionsForTopOfDialog( f, propertyTable )

	return {
	
		{
			title = LOC "$$$/EcoSee/ExportDialog/Account=EcoSee Account",
			
			synopsis = bind 'accountStatus',

			f:row {
				spacing = f:control_spacing(),

				f:static_text {
					title = bind 'accountStatus',
					alignment = 'right',
					fill_horizontal = 1,
				},

				f:push_button {
					width = 90,
					title = bind 'loginButtonTitle',
					enabled = bind 'loginButtonEnabled',
					action = function()
						require 'EcoSeeUser'
						EcoSeeUser.login( propertyTable )
					end,
				},
			},
		},
	
	}

end

-------------------------------------------------------------------------------

local kSafetyTitles = {
	safe = LOC "$$$/EcoSee/ExportDialog/Safety/Safe=Safe",
	moderate = LOC "$$$/EcoSee/ExportDialog/Safety/Moderate=Moderate",
	restricted = LOC "$$$/EcoSee/ExportDialog/Safety/Restricted=Restricted",
}

function EcoSeeExportDialogSections.sectionsForBottomOfDialog( f, propertyTable )

	return {
	
		-- {
		-- 	title = LOC "$$$/EcoSee/ExportDialog/PrivacyAndSafety=Privacy and Safety",
		-- 	synopsis = function( props )
		-- 		
		-- 		local summary = {}
		-- 		
		-- 		local function add( x )
		-- 			if x then
		-- 				summary[ #summary + 1 ] = x
		-- 			end
		-- 		end
		-- 		
		-- 		if props.privacy == 'private' then
		-- 			add( LOC "$$$/EcoSee/ExportDialog/Private=Private" )
		-- 			if props.privacy_family then
		-- 				add( LOC "$$$/EcoSee/ExportDialog/Family=Family" )
		-- 			end
		-- 			if props.privacy_friends then
		-- 				add( LOC "$$$/EcoSee/ExportDialog/Friends=Friends" )
		-- 			end
		-- 		else
		-- 			add( LOC "$$$/EcoSee/ExportDialog/Public=Public" )
		-- 		end
		-- 		
		-- 		local safetyStr = kSafetyTitles[ props.safety ]
		-- 		if safetyStr then
		-- 			add( safetyStr )
		-- 		end
		-- 		
		-- 		-- Etc. (rest left as an exercise for the reader)
		-- 		
		-- 		return table.concat( summary, " / " )
		-- 		
		-- 	end,
		-- 	
		-- 	place = 'horizontal',
		-- 	
		-- 			f:column {
		-- 				spacing = f:control_spacing() / 2,
		-- 				fill_horizontal = 1,
		-- 	
		-- 				f:row {
		-- 					f:static_text {
		-- 						title = LOC "$$$/EcoSee/ExportDialog/Privacy=Privacy:",
		-- 						alignment = 'right',
		-- 						width = share 'labelWidth',
		-- 					},
		-- 	
		-- 					f:radio_button {
		-- 						title = LOC "$$$/EcoSee/ExportDialog/Private=Private",
		-- 						checked_value = 'private',
		-- 						value = bind 'privacy',
		-- 					},
		-- 				},
		-- 	
		-- 				f:row {
		-- 					f:spacer {
		-- 						width = share 'labelWidth',
		-- 					},
		-- 	
		-- 					f:column {
		-- 						spacing = f:control_spacing() / 2,
		-- 						margin_left = 15,
		-- 						margin_bottom = f:control_spacing() / 2,
		-- 		
		-- 						f:checkbox {
		-- 							title = LOC "$$$/EcoSee/ExportDialog/Family=Family",
		-- 							value = bind 'privacy_family',
		-- 							enabled = LrBinding.keyEquals( 'privacy', 'private' ),
		-- 						},
		-- 		
		-- 						f:checkbox {
		-- 							title = LOC "$$$/EcoSee/ExportDialog/Friends=Friends",
		-- 							value = bind 'privacy_friends',
		-- 							enabled = LrBinding.keyEquals( 'privacy', 'private' ),
		-- 						},
		-- 					},
		-- 				},
		-- 	
		-- 				f:row {
		-- 					f:spacer {
		-- 						width = share 'labelWidth',
		-- 					},
		-- 	
		-- 					f:radio_button {
		-- 						title = LOC "$$$/EcoSee/ExportDialog/Public=Public",
		-- 						checked_value = 'public',
		-- 						value = bind 'privacy',
		-- 					},
		-- 				},
		-- 			},
		-- 	
		-- 			f:column {
		-- 				spacing = f:control_spacing() / 2,
		-- 	
		-- 				fill_horizontal = 1,
		-- 	
		-- 				f:row {
		-- 					f:static_text {
		-- 						title = LOC "$$$/EcoSee/ExportDialog/Safety=Safety:",
		-- 						alignment = 'right',
		-- 						width = share 'pixelpost_col2_label_width',
		-- 					},
		-- 	
		-- 					f:popup_menu {
		-- 						value = bind 'safety',
		-- 						width = share 'pixelpost_col2_popup_width',
		-- 						items = {
		-- 							{ title = kSafetyTitles.safe, value = 'safe' },
		-- 							{ title = kSafetyTitles.moderate, value = 'moderate' },
		-- 							{ title = kSafetyTitles.restricted, value = 'restricted' },
		-- 						},
		-- 					},
		-- 				},
		-- 	
		-- 				f:row {
		-- 					margin_bottom = f:control_spacing() / 2,
		-- 					
		-- 					f:spacer {
		-- 						width = share 'pixelpost_col2_label_width',
		-- 					},
		-- 	
		-- 					f:checkbox {
		-- 						title = LOC "$$$/EcoSee/ExportDialog/HideFromPublicSite=Hide from public site areas",
		-- 						value = bind 'hideFromPublic',
		-- 					},
		-- 				},
		-- 	
		-- 				f:row {
		-- 					f:static_text {
		-- 						title = LOC "$$$/EcoSee/ExportDialog/Type=Type:",
		-- 						alignment = 'right',
		-- 						width = share 'pixelpost_col2_label_width',
		-- 					},
		-- 	
		-- 					f:popup_menu {
		-- 						width = share 'pixelpost_col2_popup_width',
		-- 						value = bind 'type',
		-- 						items = {
		-- 							{ title = LOC "$$$/EcoSee/ExportDialog/Type/Photo=Photo", value = 'photo' },
		-- 							{ title = LOC "$$$/EcoSee/ExportDialog/Type/Screenshot=Screenshot", value = 'screenshot' },
		-- 							{ title = LOC "$$$/EcoSee/ExportDialog/Type/Other=Other", value = 'other' },
		-- 						},
		-- 					},
		-- 				},
		-- 			},
		-- 		},
		-- 	
		{
			title = LOC "$$$/EcoSee/ExportDialog/Organize=Batch Publish Options",

			spacing = f:control_spacing() / 2,

--[[			-- out of time to implement this]]--
			f:row {
				margin_bottom = f:control_spacing() / 2,

				f:static_text {
					title = LOC "$$$/EcoSee/ExportDialog/autoDate=Date & Time:",
					alignment = 'right',
					width = share 'labelWidth',
				},

				f:popup_menu {
					value = bind 'autoDate', 
					-- enabled = bind 'addToPhotoset',
					items = {
						-- TO DO: Should really be populated from live data. ;-)
						{ title = "Post Now", value = '2' },
						{ title = "Post One Day After Last Post", value = '1' },
						{ title = "Use EXIF Date", value = '3' },
					},
				},
--[[
				f:push_button {
					title = LOC "$$$/EcoSee/ExportDialog/NewPhotoset=New Photoset",
					--action = function() createNewPhotoset( propertyTable ) end,
						-- TO DO: Add a new photo set dialog.
]]--				},

			},


			f:row {
				f:static_text {
					title = LOC "$$$/EcoSee/ExportDialog/AddTags=Add Tags:",
					alignment = 'right',
					width = share 'labelWidth',
				},

				f:edit_field {
					value = bind 'addTags',
					fill_horizontal = 1,
				},
			},

			f:row {
				f:spacer {
					width = share 'labelWidth',
				},

				f:static_text {
					title = LOC "$$$/EcoSee/ExportDialog/TagMergeNote=These tags will be combined with the exported keywords from each photo.",
					fill_horizontal = 1,
					height_in_lines = 2,
					width_in_chars = 32,
				},
			},
			
			-- Categories:
			
			f:row {
				f:static_text {
					title = LOC "$$$/EcoSee/ExportDialog/AddTags=Add Categories:",
					alignment = 'right',
					width = share 'labelWidth',
				},

				f:edit_field {
					value = bind 'addCategories',
					fill_horizontal = 1,
				},
			},

			f:row {
				f:spacer {
					width = share 'labelWidth',
				},

				f:static_text {
					title = LOC "$$$/EcoSee/ExportDialog/TagMergeNote=You can enter specfic categores you would like each photo to be included in.",
					fill_horizontal = 1,
					height_in_lines = 2,
					width_in_chars = 32,
				},
			},
			
		f:row {
			margin_bottom = f:control_spacing() / 2,

			f:static_text {
				title = LOC "$$$/EcoSee/ExportDialog/allowComments=Comment Settings:",
				alignment = 'right',
				width = share 'labelWidth',
			},

		f:popup_menu {
			value = bind 'allowComments', 
			-- enabled = bind 'addToPhotoset',
			items = {
				-- TO DO: Should really be populated from live data. ;-)
				{ title = "Publish Instantly", value = 'A' },
				{ title = "To Moderation Que", value = 'M' },
				{ title = "Disable Commenting", value = 'F' },
			},
		},		
			},	
		
		},

	}

end
